@@ -535,7 +535,7 @@ func printFilteredProcessors(processorFilters []string, commented bool) {
 	for _, pname := range pnames {
 		creator := processors.Processors[pname]
 		output := creator()
-		printConfig(pname, output, "processors", commented)
+		printConfig(pname, output, "processors", commented, processors.Deprecations[pname])
 	}
 }
 
@@ -553,7 +553,7 @@ func printFilteredAggregators(aggregatorFilters []string, commented bool) {
 	for _, aname := range anames {
 		creator := aggregators.Aggregators[aname]
 		output := creator()
-		printConfig(aname, output, "aggregators", commented)
+		printConfig(aname, output, "aggregators", commented, aggregators.Deprecations[aname])
 	}
 }
 
@@ -591,7 +591,7 @@ func printFilteredInputs(inputFilters []string, commented bool) {
 			continue
 		}
 
-		printConfig(pname, input, "inputs", commented)
+		printConfig(pname, input, "inputs", commented, inputs.Deprecations[pname])
 	}
 
 	// Print Service Inputs
@@ -602,7 +602,7 @@ func printFilteredInputs(inputFilters []string, commented bool) {
 
 	fmt.Printf(serviceInputHeader)
 	for _, name := range servInputNames {
-		printConfig(name, servInputs[name], "inputs", commented)
+		printConfig(name, servInputs[name], "inputs", commented, inputs.Deprecations[name])
 	}
 }
 
@@ -620,7 +620,7 @@ func printFilteredOutputs(outputFilters []string, commented bool) {
 	for _, oname := range onames {
 		creator := outputs.Outputs[oname]
 		output := creator()
-		printConfig(oname, output, "outputs", commented)
+		printConfig(oname, output, "outputs", commented, outputs.Deprecations[oname])
 	}
 }
 
@@ -634,13 +634,20 @@ func printFilteredGlobalSections(sectionFilters []string) {
 	}
 }
 
-func printConfig(name string, p telegraf.PluginDescriber, op string, commented bool) {
+func printConfig(name string, p telegraf.PluginDescriber, op string, commented bool, di telegraf.DeprecationInfo) {
 	comment := ""
 	if commented {
 		comment = "# "
 	}
-	fmt.Printf("\n%s# %s\n%s[[%s.%s]]", comment, p.Description(), comment,
-		op, name)
+	fmt.Printf("\n%s# %s\n%s[[%s.%s]]", comment, p.Description(), comment, op, name)
+
+	if di.Since != "" {
+		removalNote := ""
+		if di.RemovalIn != "" {
+			removalNote = " and will be removed in " + di.RemovalIn
+		}
+		fmt.Printf("\n%s  ## DEPRECATED: The '%s' plugin is deprecated in version %s%s, %s.", comment, name, di.Since, removalNote, di.Notice)
+	}
 
 	config := p.SampleConfig()
 	if config == "" {
@@ -669,7 +676,7 @@ func sliceContains(name string, list []string) bool {
 // PrintInputConfig prints the config usage of a single input.
 func PrintInputConfig(name string) error {
 	if creator, ok := inputs.Inputs[name]; ok {
-		printConfig(name, creator(), "inputs", false)
+		printConfig(name, creator(), "inputs", false, inputs.Deprecations[name])
 	} else {
 		return fmt.Errorf("Input %s not found", name)
 	}
@@ -679,7 +686,7 @@ func PrintInputConfig(name string) error {
 // PrintOutputConfig prints the config usage of a single output.
 func PrintOutputConfig(name string) error {
 	if creator, ok := outputs.Outputs[name]; ok {
-		printConfig(name, creator(), "outputs", false)
+		printConfig(name, creator(), "outputs", false, outputs.Deprecations[name])
 	} else {
 		return fmt.Errorf("Output %s not found", name)
 	}
@@ -1666,7 +1673,7 @@ func (c *Config) missingTomlField(_ reflect.Type, key string) error {
 		"prefix", "prometheus_export_timestamp", "prometheus_ignore_timestamp", "prometheus_sort_metrics", "prometheus_string_as_label",
 		"separator", "splunkmetric_hec_routing", "splunkmetric_multimetric", "tag_keys",
 		"tagdrop", "tagexclude", "taginclude", "tagpass", "tags", "template", "templates",
-		"value_field_name", "wavefront_source_override", "wavefront_use_strict",
+		"value_field_name", "wavefront_source_override", "wavefront_use_strict", "wavefront_disable_prefix_conversion",
 		"xml", "xpath", "xpath_json", "xpath_msgpack", "xpath_protobuf", "xpath_print_document",
 		"xpath_protobuf_file", "xpath_protobuf_type":
 
