@@ -1,6 +1,7 @@
 package ifname
 
 import (
+	"errors"
 	"fmt"
 	"strconv"
 	"sync"
@@ -80,7 +81,7 @@ type valType = nameMap
 type mapFunc func(agent string) (nameMap, error)
 type makeTableFunc func(string) (*si.Table, error)
 
-type sigMap map[string](chan struct{})
+type sigMap map[string]chan struct{}
 
 type IfName struct {
 	SourceTag string `toml:"tag"`
@@ -96,24 +97,19 @@ type IfName struct {
 
 	Log telegraf.Logger `toml:"-"`
 
-	ifTable  *si.Table `toml:"-"`
-	ifXTable *si.Table `toml:"-"`
+	ifTable  *si.Table
+	ifXTable *si.Table
 
-	lock  sync.Mutex `toml:"-"`
-	cache *TTLCache  `toml:"-"`
+	cache    *TTLCache
+	lock     sync.Mutex
+	parallel parallel.Parallel
+	sigs     sigMap
 
-	parallel parallel.Parallel    `toml:"-"`
-	acc      telegraf.Accumulator `toml:"-"`
-
-	getMapRemote mapFunc       `toml:"-"`
-	makeTable    makeTableFunc `toml:"-"`
-
-	gsBase snmp.GosnmpWrapper `toml:"-"`
-
-	sigs sigMap `toml:"-"`
+	getMapRemote mapFunc
+	makeTable    makeTableFunc
 }
 
-const minRetry time.Duration = 5 * time.Minute
+const minRetry = 5 * time.Minute
 
 func (d *IfName) SampleConfig() string {
 	return sampleConfig
@@ -132,6 +128,10 @@ func (d *IfName) Init() error {
 
 	d.sigs = make(sigMap)
 
+	if _, err := snmp.NewWrapper(d.ClientConfig); err != nil {
+		return fmt.Errorf("parsing SNMP client config: %w", err)
+	}
+
 	return nil
 }
 
@@ -157,7 +157,7 @@ func (d *IfName) addTag(metric telegraf.Metric) error {
 	for {
 		m, age, err := d.getMap(agent)
 		if err != nil {
-			return fmt.Errorf("couldn't retrieve the table of interface names: %w", err)
+			return fmt.Errorf("couldn't retrieve the table of interface names for %s: %w", agent, err)
 		}
 
 		name, found := m[num]
@@ -171,7 +171,7 @@ func (d *IfName) addTag(metric telegraf.Metric) error {
 		// the interface we're interested in.  If the entry is old
 		// enough, retrieve it from the agent once more.
 		if age < minRetry {
-			return fmt.Errorf("interface number %d isn't in the table of interface names", num)
+			return fmt.Errorf("interface number %d isn't in the table of interface names on %s", num, agent)
 		}
 
 		if firstTime {
@@ -181,7 +181,7 @@ func (d *IfName) addTag(metric telegraf.Metric) error {
 		}
 
 		// not found, cache hit, retrying
-		return fmt.Errorf("missing interface but couldn't retrieve table")
+		return fmt.Errorf("missing interface but couldn't retrieve table for %v", agent)
 	}
 }
 
@@ -192,27 +192,21 @@ func (d *IfName) invalidate(agent string) {
 }
 
 func (d *IfName) Start(acc telegraf.Accumulator) error {
-	d.acc = acc
-
 	var err error
-	d.gsBase, err = snmp.NewWrapper(d.ClientConfig)
-	if err != nil {
-		return fmt.Errorf("parsing SNMP client config: %w", err)
-	}
 
-	d.ifTable, err = d.makeTable("IF-MIB::ifDescr")
+	d.ifTable, err = d.makeTable("1.3.6.1.2.1.2.2.1.2")
 	if err != nil {
-		return fmt.Errorf("looking up ifDescr in local MIB: %w", err)
+		return fmt.Errorf("preparing ifTable: %v", err)
 	}
-	d.ifXTable, err = d.makeTable("IF-MIB::ifName")
+	d.ifXTable, err = d.makeTable("1.3.6.1.2.1.31.1.1.1.1")
 	if err != nil {
-		return fmt.Errorf("looking up ifName in local MIB: %w", err)
+		return fmt.Errorf("preparing ifXTable: %v", err)
 	}
 
 	fn := func(m telegraf.Metric) []telegraf.Metric {
 		err := d.addTag(m)
 		if err != nil {
-			d.Log.Debugf("Error adding tag %v", err)
+			d.Log.Debugf("Error adding tag: %v", err)
 		}
 		return []telegraf.Metric{m}
 	}
@@ -299,27 +293,27 @@ func (d *IfName) getMap(agent string) (entry nameMap, age time.Duration, err err
 }
 
 func (d *IfName) getMapRemoteNoMock(agent string) (nameMap, error) {
-	gs := d.gsBase
-	err := gs.SetAgent(agent)
+	gs, err := snmp.NewWrapper(d.ClientConfig)
 	if err != nil {
+		return nil, fmt.Errorf("parsing SNMP client config: %w", err)
+	}
+
+	if err = gs.SetAgent(agent); err != nil {
 		return nil, fmt.Errorf("parsing agent tag: %w", err)
 	}
 
-	err = gs.Connect()
-	if err != nil {
+	if err = gs.Connect(); err != nil {
 		return nil, fmt.Errorf("connecting when fetching interface names: %w", err)
 	}
 
 	//try ifXtable and ifName first.  if that fails, fall back to
 	//ifTable and ifDescr
 	var m nameMap
-	m, err = buildMap(gs, d.ifXTable, "ifName")
-	if err == nil {
+	if m, err = buildMap(gs, d.ifXTable); err == nil {
 		return m, nil
 	}
 
-	m, err = buildMap(gs, d.ifTable, "ifDescr")
-	if err == nil {
+	if m, err = buildMap(gs, d.ifTable); err == nil {
 		return m, nil
 	}
 
@@ -346,12 +340,13 @@ func init() {
 	})
 }
 
-func makeTableNoMock(fieldName string) (*si.Table, error) {
+func makeTableNoMock(oid string) (*si.Table, error) {
 	var err error
 	tab := si.Table{
+		Name:       "ifTable",
 		IndexAsTag: true,
 		Fields: []si.Field{
-			{Oid: fieldName},
+			{Oid: oid, Name: "ifName"},
 		},
 	}
 
@@ -364,7 +359,7 @@ func makeTableNoMock(fieldName string) (*si.Table, error) {
 	return &tab, nil
 }
 
-func buildMap(gs snmp.GosnmpWrapper, tab *si.Table, column string) (nameMap, error) {
+func buildMap(gs snmp.GosnmpWrapper, tab *si.Table) (nameMap, error) {
 	var err error
 
 	rtab, err := tab.Build(gs, true)
@@ -389,13 +384,13 @@ func buildMap(gs snmp.GosnmpWrapper, tab *si.Table, column string) (nameMap, err
 		if err != nil {
 			return nil, fmt.Errorf("index tag isn't a uint")
 		}
-		nameIf, ok := v.Fields[column]
+		nameIf, ok := v.Fields["ifName"]
 		if !ok {
-			return nil, fmt.Errorf("field %s is missing", column)
+			return nil, errors.New("ifName field is missing")
 		}
 		name, ok := nameIf.(string)
 		if !ok {
-			return nil, fmt.Errorf("field %s isn't a string", column)
+			return nil, errors.New("ifName field isn't a string")
 		}
 
 		t[i] = name
